==> qtwayland-opensource-src_5.4.1.orig.tar.xz: qtwayland-opensource-src-5.4.1/src/compositor/compositor_api/qwaylandsurfaceview.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Jolla Ltd, author: <giulio.camuffo@jollamobile.com>
** Contact: http://www.qt-project.org/legal
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and Digia.  For licensing terms and
** conditions see http://qt.digia.com/licensing.  For further information
** use the contact form at http://qt.digia.com/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 as published by the Free Software
** Foundation and appearing in the file LICENSE.LGPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU Lesser General Public License version 2.1 requirements
** will be met: http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** In addition, as a special exception, Digia gives you certain additional
** rights.  These rights are described in the Digia Qt LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3.0 as published by the Free Software
** Foundation and appearing in the file LICENSE.GPL included in the
** packaging of this file.  Please review the following information to
** ensure the GNU General Public License version 3.0 requirements will be
** met: http://www.gnu.org/copyleft/gpl.html.
**
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qwaylandsurfaceview.h"
#include "qwaylandsurface.h"
#include "qwaylandsurface_p.h"

QT_BEGIN_NAMESPACE

class QWaylandSurfaceViewPrivate
{
public:
    QWaylandSurface *surface;
    QPointF pos;
};

QWaylandSurfaceView::QWaylandSurfaceView(QWaylandSurface *surf)
                   : d(new QWaylandSurfaceViewPrivate)
{
    d->surface = surf;
    if (surf) {
        surf->d_func()->views << this;
        surf->ref();
    }
}

QWaylandSurfaceView::~QWaylandSurfaceView()
{
    if (d->surface) {
        d->surface->destroy();
        d->surface->d_func()->views.removeOne(this);
    }
    delete d;
}

QWaylandSurface *QWaylandSurfaceView::surface() const
{
    return d->surface;
}

QWaylandCompositor *QWaylandSurfaceView::compositor() const
{
    return d->surface ? d->surface->compositor() : 0;
}

void QWaylandSurfaceView::setPos(const QPointF &pos)
{
    d->pos = pos;
}

QPointF QWaylandSurfaceView::pos() const
{
    return d->pos;
}

QT_END_NAMESPACE

==> qtwayland-opensource-src_5.5.1.orig.tar.xz: qtwayland-opensource-src-5.5.1/src/compositor/compositor_api/qwaylandsurfaceview.cpp <==
/****************************************************************************
**
** Copyright (C) 2014 Jolla Ltd, author: <giulio.camuffo@jollamobile.com>
** Contact: http://www.qt.io/licensing/
**
** This file is part of the plugins of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:LGPL21$
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see http://www.qt.io/terms-conditions. For further
** information use the contact form at http://www.qt.io/contact-us.
**
** GNU Lesser General Public License Usage
** Alternatively, this file may be used under the terms of the GNU Lesser
** General Public License version 2.1 or version 3 as published by the Free
** Software Foundation and appearing in the file LICENSE.LGPLv21 and
** LICENSE.LGPLv3 included in the packaging of this file. Please review the
** following information to ensure the GNU Lesser General Public License
** requirements will be met: https://www.gnu.org/licenses/lgpl.html and
** http://www.gnu.org/licenses/old-licenses/lgpl-2.1.html.
**
** As a special exception, The Qt Company gives you certain additional
** rights. These rights are described in The Qt Company LGPL Exception
** version 1.1, included in the file LGPL_EXCEPTION.txt in this package.
**
** $QT_END_LICENSE$
**
****************************************************************************/

#include "qwaylandsurfaceview.h"
#include "qwaylandsurface.h"
#include "qwaylandsurface_p.h"
#include "qwaylandcompositor.h"
#include "qwaylandinput.h"

QT_BEGIN_NAMESPACE

class QWaylandSurfaceViewPrivate
{
public:
    QWaylandSurface *surface;
    QPointF pos;
};

QWaylandSurfaceView::QWaylandSurfaceView(QWaylandSurface *surf)
                   : d(new QWaylandSurfaceViewPrivate)
{
    d->surface = surf;
    if (surf) {
        surf->d_func()->views << this;
        surf->ref();
    }
}

QWaylandSurfaceView::~QWaylandSurfaceView()
{
    if (d->surface) {
        QWaylandInputDevice *i = d->surface->compositor()->defaultInputDevice();
        if (i->mouseFocus() == this)
            i->setMouseFocus(Q_NULLPTR, QPointF());

        d->surface->destroy();
        d->surface->d_func()->views.removeOne(this);
    }
    delete d;
}

QWaylandSurface *QWaylandSurfaceView::surface() const
{
    return d->surface;
}

QWaylandCompositor *QWaylandSurfaceView::compositor() const
{
    return d->surface ? d->surface->compositor() : 0;
}

void QWaylandSurfaceView::setPos(const QPointF &pos)
{
    d->pos = pos;
}

QPointF QWaylandSurfaceView::pos() const
{
    return d->pos;
}

QT_END_NAMESPACE
